@@ -333,13 +333,13 @@ def userInGroup(userName, groupName):
 
 	return False
 
-def syncgroup(group, hubname = "", purgeorphans = True, addgroupmemberships = True):
-	_syncgroups(hubname,purgeorphans,addgroupmemberships,group)
+def syncgroup(group, hubname = "", purgeorphans = True, addgroupmemberships = True, verbose = False, debug = False):
+	_syncgroups(hubname,purgeorphans,addgroupmemberships,group,verbose,debug)
 
-def syncgroups(hubname = "", purgeorphans = True, addgroupmemberships = True):
-    _syncgroups(hubname,purgeorphans,addgroupmemberships,'*')
+def syncgroups(hubname = "", purgeorphans = True, addgroupmemberships = True, verbose = False, debug = False):
+    _syncgroups(hubname,purgeorphans,addgroupmemberships,'*',verbose,debug)
 
-def _syncgroups(hubname = "", purgeorphans = True, addgroupmemberships = True, group = '*'):
+def _syncgroups(hubname = "", purgeorphans = True, addgroupmemberships = True, group = '*', verbose = False, debug = False):
 	
 	dbPW = hubzero.config.webconfig.getWebConfigDBPassword()
 	dbUserName = hubzero.config.webconfig.getWebConfigDBUsername()
@@ -374,14 +374,15 @@ def _syncgroups(hubname = "", purgeorphans = True, addgroupmemberships = True, g
 				r = l.search_s("cn="+group+",ou=groups," + siteSuffix, ldap.SCOPE_SUBTREE, '(objectClass=posixGroup)',   ['cn']) 
 
 		except ldap.NO_SUCH_OBJECT:
-			print "No groups found"
-			return
+			if debug:
+				print "No groups found"
 	
 		# delete any group in ldap that isn't in the database
 		for dn,entry in r:
 			cn = str(entry['cn'][0])
 			if cn not in groupsFromDB:
-				print "deleting: " + cn
+				if verbose:
+					print "deleting ldap group '" + cn + "'"
 				hubzero.utilities.group.delete_ldap_group(cn)	
 	
 
@@ -410,13 +411,13 @@ def _syncgroups(hubname = "", purgeorphans = True, addgroupmemberships = True, g
 				groupMembers.append(str(userGroupMembership.uidNumber))
 
 		try:
-			print "syncing ldap group: " + group.cn
+			print "syncing ldap group '" + group.cn + "'"
 			add_ldap_group(group.cn, group.description, group.gidNumber, groupMembers)
 		except ldap.ALREADY_EXISTS:
 			delete_ldap_group(group.cn)
 			add_ldap_group(group.cn, group.description, group.gidNumber, groupMembers)
 
-		if groupMembers:
+		if groupMembers and debug:
 			print "  adding members:" + str(groupMembers)
 
 
