@@ -707,14 +707,13 @@ def add_ldap_user2(cn,
 		#	traceback.print_exc()
 		
 
-def syncuser(user, hubname = "", purgeorphans = True, syncattributes = True):
-     _syncusers(hubname, purgeorphans, syncattributes, user)
+def syncuser(user, hubname = "", purgeorphans = True, syncattributes = True, verbose = False, debug = False):
+     _syncusers(hubname, purgeorphans, syncattributes, user, verbose, debug)
 
-def syncusers(hubname = "", purgeorphans = True, syncattributes = True):
-     _syncusers(hubname, purgeorphans, syncattributes, '*')
+def syncusers(hubname = "", purgeorphans = True, syncattributes = True, verbose = False, debug = False):
+     _syncusers(hubname, purgeorphans, syncattributes, '*', verbose, debug)
 
-def _syncusers(hubname = "", purgeorphans = True, syncattributes = True, user = '*'):
-	
+def _syncusers(hubname = "", purgeorphans = True, syncattributes = True, user = '*', verbose = False, debug = False):
 	dbPW = hubzero.config.webconfig.getWebConfigDBPassword()
 	dbUserName = hubzero.config.webconfig.getWebConfigDBUsername()
 	dbName = hubzero.config.webconfig.getWebConfigDBName()
@@ -725,7 +724,8 @@ def _syncusers(hubname = "", purgeorphans = True, syncattributes = True, user =
 	# the length of time it would take this script to run, so we do it this way
 	if purgeorphans:
 
-		print "Orphaned users in ldap without a corresponding group in the database will be DELETED"
+		if debug:
+			print "Orphaned users in ldap without a corresponding group in the database will be DELETED"
 
 		# grab all users from db and store them off for easy lookup
 		if user == '*':
@@ -756,11 +756,13 @@ def _syncusers(hubname = "", purgeorphans = True, syncattributes = True, user =
 			uid = str(entry['uid'][0])
 			
 			if uid not in usersFromDB:
-				print "uid: " + str(uid) + " not in database, must delete"
+				if verbose:
+					print "deleting ldap user '" + uid + "'"
 				try:
 					hubzero.utilities.user.delete_ldap_user(uid)
 				except ldap.NO_SUCH_OBJECT:
-					print " user not found"
+					if debug:
+						print " user not found"
 
 	# now do a mass add of all users from db	
 	if user == '*':
@@ -769,6 +771,7 @@ def _syncusers(hubname = "", purgeorphans = True, syncattributes = True, user =
 		sql = "SELECT `username`, `name`, `userPassword`, `uidNumber`, `homeDirectory`, `loginShell`, `gid`, gidNumber from jos_xprofiles WHERE username='" + user + "'"
 	
 	for duser in db.query(sql, None):
-		print "syncing user:" + duser.username
+		if verbose:
+			print "syncing ldap user '" + duser.username + "'"
 		_syncuser(duser.username, hubname, syncattributes)
 	
\ No newline at end of file
